/*
 EPSHeader

   File: 80x40.e
   Author: T. Menn
   Created: Thu, 10/24/1991  12:04:42
*/
/*
 EPSRevision History

   J. Kercheval  Thu, 10/24/1991  12:06:08  modify for command line loading
   J. Kercheval  Thu, 10/24/1991  12:42:18  add comments and mode_dir define
*/

/* 
 * this module implements a 40 line mode for VGA systems and (with some
 * modification) a 35 line EGA mode.  On exit, the system should be reset to
 * its previous video mode.  This routine is callable via set_video() and
 * next_video().  Loading the byte file and saving the state file will allow
 * you to access the 40 line video mode in the standard way (ie -vl40).  If
 * you wish to load this from the command line then a batch file which looks
 * as follows would do well: epsilon -l80x40 -vl40 %1 %2 %3 %4 %5 %6 %7 %8 %9
 * mode co80 If this is loaded in the batch file fashion then the video mode
 * needs to be reset on exit (thus the mode co80).  
 *
 *
 * The 82 byte com program EGA35 is from a code fragment placed in PC
 * Magazine some years ago and is as close to Public Domain as you get.  The
 * source is included as 80x40.scr and the com file as 80x40.com.  The com
 * file should not actually be needed, but I have not taken the time to
 * implement the lowlevel calls from within epsilon (I know, I know...).  I
 * hope someone (maybe Lugaru) will take an interest in implementing this and
 * doing away with the com file completely (it would be much faster and
 * elegant.
 *
 * Hope this works well for those in need...
 *
 *                          jbk
 */


#include "eel.h"
#include "lowlevel.h"

/* set this to the path where ega35.com is placed */
#define mode_dir "ega35.com"

short	_last_video_mode;
video_mode_80x40(active)
{
	if (isega() != 1 && isega() != 2)
		return(0);
	if (active == 0)
		vid_romset(0, 0, 40);
	if (shell(mode_dir, "", "") == -1) {
		say("error executing video_mode_80x40:%d", errno);
		return(0);
	}
	_last_video_mode = -2;
	m_regs.w.cx = 0x0507;
	vid_int(0x100);		/* set up the cursor */
	m_regs.b.bh = 7;	/* attribute to clear with */
	m_regs.w.cx = 0;	/* upper left, lower right of 80x80 */
	m_regs.w.dx = 0x5050;	/* screen, to ensure we get all */
	vid_int(0x600);		/* clear screen by scrolling */
	term_position(0, 0);
	leave_blank = 1;	/* note that screen's clear */
	return(1);
}

when_loading() 
{
    video_mode_80x40(0);
}
